@@ -557,7 +557,7 @@ add_bwrap (GPtrArray   *array,
   add_args (array,
 	    "bwrap",
 	    "--ro-bind", "/usr", "/usr",
-	    "--ro-bind", "/etc/ld.so.cache", "/etc/ld.so.cache",
+	    "--ro-bind-try", "/etc/ld.so.cache", "/etc/ld.so.cache",
 	    NULL);
 
   /* These directories might be symlinks into /usr/... */
